from django.contrib import admin
from django.contrib.sites.models import Site

from polynum.base.models import *

class ProfileAdmin(admin.ModelAdmin):
    filter_horizontal = [ 'choices', ]
    list_display = ['id', 'order', 'name', 'display_choices', 'ppd', 'ppp']
    list_editable = ['name', 'order', 'ppd', 'ppp']

admin.site.register(Profile, ProfileAdmin)

class ProfileOptionChoiceInline(admin.StackedInline):
    model = ProfileOptionChoice

class ProfileOptionAdmin(admin.ModelAdmin):
    inlines = [ ProfileOptionChoiceInline, ]
    list_display = ['id', 'order', 'name', 'visible', 'list_type', 'display_choices']
    list_editable = ['name', 'order', 'visible', 'list_type']

admin.site.register(ProfileOption, ProfileOptionAdmin)

class ChildrenRelationInline(admin.TabularInline):
    model = EntityRelation
    fk_name = 'parent'
    raw_id_fields = ['child']

    def queryset(self, request):
        return super(ChildrenRelationInline, self).queryset(request).filter(direct=True)

class ParentRelationInline(admin.TabularInline):
    model = EntityRelation
    fk_name = 'child'
    raw_id_fields = ['parent']

    def queryset(self, request):
        return super(ParentRelationInline, self).queryset(request).filter(direct=True)

class AccountingCodeInline(admin.TabularInline):
    model = AccountingCode

class EntityAdmin(admin.ModelAdmin):
    list_display = ['code', 'get_name', 'get_description']
    list_filter = ['depth']
    search_fields = ['name', 'description', 'code']
    inlines = [ChildrenRelationInline, ParentRelationInline]

class HistoryInline(admin.TabularInline):
    model = History

class RequestAdmin(admin.ModelAdmin):
    raw_id_fields = [ 'entity' ]
    list_display = ['id', 'user', 'uploadfile', 'name', 'nb_pages', 'entity',  ]
    date_hierarchy = 'delivery_date'
    list_filter = ['status', 'delivery_date', 'creation_date', 'usage',
            'licence', 'copyright', 'usage' ]
    inlines = [ HistoryInline ]

class TransitionAdmin(admin.ModelAdmin):
    list_display = [ 'id', 'role', 'source', 'action', 'destination',
            'default', 'warn' ]
    list_editable = ['role', 'source', 'action', 'destination']
    list_filter = [ 'role', 'source', 'action', 'destination' ]

class MailNotificationInline(admin.TabularInline):
    model = MailNotification
    list_display = ('action', 'to', 'subject')
    list_filter = ('action', 'to')

class ActionAdmin(admin.ModelAdmin):
    inlines = [ MailNotificationInline ]
    list_display = ('id', 'name', 'comment', 'special_type', 'pages',
            'validate_request' )
    list_filter = ('comment', 'special_type', 'validate_request')
    list_editable = [ 'name', 'comment', 'special_type', 'validate_request' ]

class StatusAdmin(admin.ModelAdmin):
    list_display = ('id', 'name', 'order', 'visible', 'default', 'start', 'end')
    list_editable = ('name', 'order', 'visible', 'default', 'start', 'end')
    list_filter = ('visible', 'default', 'start', 'end')

admin.site.register(Entity, EntityAdmin)
admin.site.register(EntityType)

admin.site.register(Role)

class RoleAssociationAdmin(admin.ModelAdmin):
    raw_id_fields = [ 'entity' ]
    list_display = [ 'id', 'group', 'entity', 'role', 'description' ]
    list_editable = [ 'group', 'entity', 'role', 'description' ]
    list_filter = [ 'group', 'entity', 'role', 'description' ]

admin.site.register(RoleAssociation, RoleAssociationAdmin)

class DeliveryPlaceAdmin(admin.ModelAdmin):
    list_display = [ 'id', 'order', 'name', 'description', 'comments' ]
    list_editable = [ 'order', 'name', 'description', 'comments' ]

admin.site.register(DeliveryPlace, DeliveryPlaceAdmin)

class DocumentUsageAdmin(admin.ModelAdmin):
    list_display = [ 'id', 'order', 'name', 'description', 'url', 'comments' ]
    list_editable = [ 'order', 'name', 'description', 'url', 'comments' ]

admin.site.register(DocumentUsage, DocumentUsageAdmin)

class DocumentLicenceAdmin(admin.ModelAdmin):
    list_display = [ 'id', 'order', 'name', 'description', 'url', 'comments' ]
    list_editable = [ 'order', 'name', 'description', 'url', 'comments' ]

admin.site.register(DocumentLicence, DocumentLicenceAdmin)
admin.site.register(Request, RequestAdmin)

admin.site.register(Status, StatusAdmin)
admin.site.register(Action, ActionAdmin)
admin.site.register(Transition, TransitionAdmin)

# don't show the "Site" model
admin.site.unregister(Site)

