"""CAS authentication backend"""

try:
    import ldap
    import ldap.filter
except ImportError:
    ldap = None

from django_cas.backends import CASBackend
from django.contrib.auth.backends import ModelBackend
from django.core.cache import cache

from .models.user import User
from .. import app_settings

class PolynumBackendMixin(object):
    def get_user(self, user_id):
        """Retrieve the user's entry in the User model if it exists"""
        try:
            return User.objects.get(pk=user_id)
        except User.DoesNotExist:
            return None

class CASBackend(PolynumBackendMixin, CASBackend):
    USER_ATTRIBUTES = {
            'mail': 'email',
            'givenName': 'first_name',
            'sn': 'last_name',
          }
    def query_ldap(self, user):
        r = []
        if ldap:
            try:
                cache_key = 'ldap_query_%s' % user.username
                r = cache.get(cache_key)
                if r is None:
                    connection = ldap.initialize(app_settings.LDAP_URL)
                    connection.simple_bind_s(app_settings.LDAP_BIND_DN,
                            app_settings.LDAP_BIND_PASSWORD)
                    ldap_filter = ldap.filter.filter_format(app_settings.LDAP_USER_QUERY, (user.username,))
                    r = connection.search_s(app_settings.LDAP_BASE,
                            ldap.SCOPE_SUBTREE,
                            ldap_filter,
                            ['mail', 'telephoneNumber', 'supannAutreTelephone', 'roomNumber' ])
                    cache.set(cache_key, r, 600)
            except ldap.LDAPError, e:
                pass
        return r

    def get_user(self, user_id):
        user = super(CASBackend, self).get_user(user_id)
        self.populate_from_ldap(user)
        return user

    def populate_from_ldap(self, user):
        if not user:
            return
        r = self.query_ldap(user)
        if r:
            for key in r[0][1]:
                value = r[0][1][key][0]
                setattr(user, key, value)
                if key in self.USER_ATTRIBUTES:
                    setattr(user, self.USER_ATTRIBUTES[key], value)

class ModelBackend(PolynumBackendMixin, ModelBackend):
    pass
