# -*- coding: utf-8 -*-
"""
Gestion des rôles et autorisations :
- un groupe a des rôles sur certaines entités
- un rôles peut faire certaines actions sur les demandes selon leur status
"""

from django.contrib.auth.models import Group
from django.db import models
from django.utils.translation import ugettext_lazy as _

class Role(models.Model):

    class Meta:
        app_label = 'base'
        verbose_name = _(u'Rôle')
        verbose_name_plural = _(u'Rôles')

    def __unicode__(self):
        return self.name

    id = models.CharField(max_length=40, primary_key=True, verbose_name=_(u'Code rôle'))
    name = models.CharField(max_length=128, verbose_name=_(u'Nom du rôle'))


class RoleAssociation(models.Model):

    class Meta:
        app_label = 'base'
        verbose_name = _(u"Association groupe,entité -> rôle")
        verbose_name_plural = _(u"Associations groupe,entité -> rôle")

    def __unicode__(self):
        return u'%s,%s -> %s' % (self.group, self.entity, self.role)

    group = models.ForeignKey(Group, verbose_name=_(u'Groupe'))
    entity = models.ForeignKey('Entity', verbose_name=_(u'Entité administrative'), on_delete=models.DO_NOTHING)
    role = models.ForeignKey('Role', verbose_name=_(u'Rôle'))
    description = models.TextField(verbose_name=_(u'Description'), blank=True)

